==> sigutils-2.2.7.tar.gz: sigutils-2.2.7/SigUtils/mysql.py <==
# -*- coding: iso-8859-1 -*-

__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.04"
__DataAlteracao__ = "17/11/2011"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('mysql.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tTratamento de bases de dados em MySQL'
        else:
           print('\n\nmysql.py - Tratamento de bases de dados em MySQL \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\nmysql.py - Tratamento de bases de dados em MySQL \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')

"""Classe MySQLSig
   Autor: Luiz Fernando (luiz@sig.inf.br)
   Funcao: tratar a base de dados Mysql
                                            """
import MySQLdb

class MySQLSig:
    """sintaxe: MySQLSig(NomeDoHost, NomeDoUsuario, Senha, BancoDeDados)
       NomeDoHost: IP da maquina onde esta o banco de dados
       NomeDoUsuario: Nome do usuario cadastrado no banco
       Senha: Senha do usuario
       BancoDeDados: Nome do banco a ser usado no MySQL
       Para qualquer erro, retorna -1"""

    def __init__(self, host, user, passwd, db, porta=3306, dicionario='N'):
        self.hostName = host
        self.usuario = user
        self.senha = passwd
        self.bancoDeDados = db
        self.porta = porta
        self.dicionario = dicionario
        self.ErroCod = 0
        self.ErroDesc = ''
        self.__conecta__()

    def __conecta__(self):
        """Efetua a coneccao com o bd.
        É executado automaticamente qdo a classe é instanciada"""
        self.qtdLinhas=0
        self.ultimoSql='' # usado apenas por lerQueryUmaLinha
        try:
           self.db = MySQLdb.connect(host=self.hostName, user=self.usuario, passwd=self.senha, db=self.bancoDeDados, port=self.porta)
           if self.dicionario == 'S':
              self.cursor = self.db.cursor(cursorclass=MySQLdb.cursors.DictCursor)
           else:
              self.cursor = self.db.cursor()
        except MySQLdb.Error, e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]

    def executaQuery(self, sql):
        """executa um insert / update """
        try:
           self.qtdLinhas = self.cursor.execute(sql)
        except MySQLdb.Error, e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]
           return
        return self.qtdLinhas

    def lerQueryTudo(self, sql):
        """executa todas as linhas de um select"""
        try:
           self.qtdLinhas = self.cursor.execute(sql)
        except MySQLdb.Error, e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]
           return
        return self.cursor.fetchall()

    def lerQueryUmaLinha(self, sql):
        """executa um select e retorna uma linha de cada vez.
        O select somente é executado na primeira vez, nas demais apenas retorna as linha ja lidas.
        Caso nao tenha mais, e chamando esta funcao novamente, fará outro select.
        Se quizer fazer outro select antes de ler a ultima linha, envie o sql vazio"""
        if sql=='':
           self.ultimoSql=''
           return
        try:
           if sql != self.ultimoSql:
              self.qtdLinhas=self.cursor.execute(sql)
              self.ultimoSql = sql
           linha = self.cursor.fetchone()
           if linha=='':
              self.ultimoSql=''
        except MySQLdb.Error, e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]
           return
        except:
           return
        return linha

    def getQtdLinhas(self):
        """Retorna a quantidade de linhas do ultimo select"""
        return self.qtdLinhas

    def desconecta(self):
        try:
           self.db.close()
        except:
           pass

    def commit(self):
        self.db.commit()

    def rollback(self):
        self.db.rollback()

    def getErroCod(self):
        return self.ErroCod

    def getErroDesc(self):
        return self.ErroDesc

class sql:
    """Monta sentença sql """
    def __init__(self, tabela):
        self.tabela=tabela
        self.dicionario = {}
        self.sql=''
    def incluirColuna(self, nome, valor):
        self.dicionario[nome]=valor
    def retornarSentenca(self):
        lista=self.dicionario.keys()
        colunaNomes=''
        colunaDados=''
        for a in lista:
            colunaNomes=colunaNomes + ', ' + str(a)
            colunaDados=colunaDados + ', ' + "'" + str(self.dicionario[a]) +"'"
        colunaNomes=colunaNomes[2:]
        colunaDados=colunaDados[2:]
        self.sql=('insert into ' + self.tabela +' ('
                 +colunaNomes + ') values ('
                 +colunaDados + ')')
        return self.sql
# fim de arquivo

==> sigutils-3.1.11.tar.gz: sigutils-3.1.11/SigUtils/mysql.py <==
# -*- coding: iso-8859-1 -*-

__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.04"
__DataAlteracao__ = "17/11/2011"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(('mysql.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) +
                  '\tTratamento de bases de dados em MySQL')
        else:
            print(('\n\nmysql.py - Tratamento de bases de dados em MySQL \n' + 'Versao: ' +
                   __Versao__ + '\n' + 'Data: '+ __DataAlteracao__ + '\n'))
    except:
        print(('\n\nmysql.py - Tratamento de bases de dados em MySQL \n' + 'Versao: '+ __Versao__ +
               '\n' + 'Data: '+ __DataAlteracao__ + '\n'))

"""Classe MySQLSig
   Autor: Luiz Fernando (luiz@sig.inf.br)
   Funcao: tratar a base de dados Mysql
                                            """
import pymysql

class MySQLSig:
    """sintaxe: MySQLSig(NomeDoHost, NomeDoUsuario, Senha, BancoDeDados)
       NomeDoHost: IP da maquina onde esta o banco de dados
       NomeDoUsuario: Nome do usuario cadastrado no banco
       Senha: Senha do usuario
       BancoDeDados: Nome do banco a ser usado no MySQL
       Para qualquer erro, retorna -1"""

    def __init__(self, host, user, passwd, db, porta=3306, dicionario='N'):
        self.hostName = host
        self.usuario = user
        self.senha = passwd
        self.bancoDeDados = db
        self.porta = porta
        self.dicionario = dicionario
        self.ErroCod = 0
        self.ErroDesc = ''
        self.__conecta__()

    def __conecta__(self):
        """Efetua a coneccao com o bd.
        É executado automaticamente qdo a classe é instanciada"""
        self.qtdLinhas=0
        self.ultimoSql='' # usado apenas por lerQueryUmaLinha
        try:
           self.db = pymysql.connect(host=self.hostName, user=self.usuario, passwd=self.senha,
                                     db=self.bancoDeDados, port=self.porta)
           if self.dicionario == 'S':
              self.cursor = self.db.cursor(cursorclass=pymysql.cursors.DictCursor)
           else:
              self.cursor = self.db.cursor()
        except pymysql.Error as e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]

    def executaQuery(self, sql):
        """executa um insert / update """
        try:
           self.qtdLinhas = self.cursor.execute(sql)
        except pymysql.Error as e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]
           return
        return self.qtdLinhas

    def lerQueryTudo(self, sql):
        """executa todas as linhas de um select"""
        try:
           self.qtdLinhas = self.cursor.execute(sql)
        except pymysql.Error as e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]
           return
        return self.cursor.fetchall()

    def lerQueryUmaLinha(self, sql):
        """executa um select e retorna uma linha de cada vez.
        O select somente é executado na primeira vez, nas demais apenas retorna as linha ja lidas.
        Caso nao tenha mais, e chamando esta funcao novamente, fará outro select.
        Se quizer fazer outro select antes de ler a ultima linha, envie o sql vazio"""
        if sql=='':
           self.ultimoSql=''
           return
        try:
           if sql != self.ultimoSql:
              self.qtdLinhas=self.cursor.execute(sql)
              self.ultimoSql = sql
           linha = self.cursor.fetchone()
           if linha=='':
              self.ultimoSql=''
        except pymysql.Error as e:
           self.ErroCod=e.args[0]
           self.ErroDesc=e.args[1]
           return
        except:
           return
        return linha

    def getQtdLinhas(self):
        """Retorna a quantidade de linhas do ultimo select"""
        return self.qtdLinhas

    def desconecta(self):
        try:
           self.db.close()
        except:
           pass

    def commit(self):
        self.db.commit()

    def rollback(self):
        self.db.rollback()

    def getErroCod(self):
        return self.ErroCod

    def getErroDesc(self):
        return self.ErroDesc

class sql:
    """Monta sentença sql """
    def __init__(self, tabela):
        self.tabela=tabela
        self.dicionario = {}
        self.sql=''
    def incluirColuna(self, nome, valor):
        self.dicionario[nome]=valor
    def retornarSentenca(self):
        lista=list(self.dicionario.keys())
        colunaNomes=''
        colunaDados=''
        for a in lista:
            colunaNomes=colunaNomes + ', ' + str(a)
            colunaDados=colunaDados + ', ' + "'" + str(self.dicionario[a]) +"'"
        colunaNomes=colunaNomes[2:]
        colunaDados=colunaDados[2:]
        self.sql=('insert into ' + self.tabela +' ('
                 +colunaNomes + ') values ('
                 +colunaDados + ')')
        return self.sql
# fim de arquivo
